/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Name:		simpleBlur.fx									   		   //
// Programmierung:	Alexander Esslinger										   //
// Copyright:		Copyright  2005 by Sebastian Leopold								   //
//-------------------------------------------------------------------------------------------------------------------------//
// Beschreibungen:	HLSL Effekt fr einfaches Bluring einer Textur.							   //
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////


// Texture ( postTexture1 ) wird von Sylex 3.0 fr
// Postprocessing Effekte gesetzt
texture postTex1;

// Anzahl der Pixeloffsets und Gewichte
static const int g_c_PixelOffsetSize = 13;

// Pixeloffsets fr 6x6
float2 PixelOffsets[g_c_PixelOffsetSize] =
{
	{ -0.003, 0 },
	{ -0.0025, 0 },
	{ -0.002, 0 },
	{ -0.0015, 0 },
	{ -0.001, 0 },
	{ -0.0005, 0 },
	{  0.000, 0 },
	{  0.0005, 0 },
	{  0.001, 0 },	
	{  0.0015, 0 },
	{  0.002, 0 },
	{  0.0025, 0 },
	{  0.003, 0 },
};

// Pixelgewischte fr 6x6
static const float BlurWeights[g_c_PixelOffsetSize] =
{
	0.002216,
	0.008764,
	0.026995,
	0.064759,
	0.120985,
	0.176033,
	0.199471,
	0.176033,
	0.120985,
	0.064759,
	0.026995,
	0.008764,
	0.002216,
};


// Sampler der Textur
sampler screenTexture = sampler_state
{
	texture = (postTex1);
	MagFilter = linear;
	MinFilter = linear;
	MipFilter = linear;
	AddressU		= Clamp;
	AddressV		= Clamp;
};

// Fragmentprogramm Pixel
float4 SimpleBlur_PS(float2 tex0 : TEXCOORD0) : COLOR
{
	// Aktuellen Pixel samplen:
	float4 pixel = 0;
	
	// Blur berechnen
	for(int i = 0; i < g_c_PixelOffsetSize; i++)
	{
		pixel += tex2D(screenTexture ,tex0 + PixelOffsets[i].xy * 5) * BlurWeights[i];
	}

	if(pixel.a > 0.1) {
	pixel.a = 0.3;
	}

	return pixel;		
}

// Technik 1
Technique t0
{
	// Pass 1
	Pass p0
	{
		// Alphablending aktivieren
		AlphaBlendEnable = TRUE;
		
		// Pixelshader aktivieren
		PixelShader  = compile ps_2_0 SimpleBlur_PS();
	}
}
